# omniblack-css

A simple css generator using context managers.

## Example


```python

from omniblack.css import Sheet

with Sheet('./out.css') as sheet:
    with sheet.rule('.css-class'):
        sheet.property('color', 'purple')
```
